@@ -1,12 +1,13 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 
 import json
 from copy import deepcopy
-from typing import Any, Dict, List, Optional, Set, Tuple
+from typing import Any, Dict, List, Optional
 
 from mitosheet.state import State
 from mitosheet.step_performers.bulk_old_rename.deprecated_utils import \
@@ -44,16 +45,16 @@ class BulkOldRenameStepPerformer(StepPerformer):
         return 'old_rename_only_use_this_in_testing'
 
     @classmethod
-    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
+    def saturate(cls, prev_state: State, params) -> Dict[str, str]:
         return params
 
     @classmethod
-    def execute( # type: ignore
+    def execute(
         cls,
         prev_state: State,
         move_to_deprecated_id_algorithm: bool=False,
-        **params: Any
-    ) -> Tuple[State, Optional[Dict[str, Any]]]:
+        **params
+    ) -> State:
         """
         If move_to_deprecated_id_algorithm, then this step is being
         used at the start of a replayed analysis to stand in for
@@ -65,7 +66,7 @@ class BulkOldRenameStepPerformer(StepPerformer):
         do not have their analysis break when they upgrade.
         """
 
-        post_state = prev_state.copy(deep_sheet_indexes=list(range(len(prev_state.dfs))))
+        post_state = deepcopy(prev_state)
 
         column_header_renames_list = []
         for sheet_index, df in enumerate(prev_state.dfs):
@@ -75,12 +76,11 @@ class BulkOldRenameStepPerformer(StepPerformer):
 
             for old_column_header, new_column_header in column_header_renames.items():
                 column_id = post_state.column_ids.get_column_id_by_header(sheet_index, old_column_header)
-                rename_column_headers_in_state(
+                post_state = rename_column_headers_in_state(
                     post_state,
                     sheet_index,
                     column_id,
-                    new_column_header,
-                    None
+                    new_column_header
                 )
 
         if move_to_deprecated_id_algorithm:
@@ -92,7 +92,7 @@ class BulkOldRenameStepPerformer(StepPerformer):
         
 
     @classmethod
-    def transpile( # type: ignore
+    def transpile(
         cls,
         prev_state: State,
         post_state: State,
@@ -101,7 +101,7 @@ class BulkOldRenameStepPerformer(StepPerformer):
     ) -> List[str]:
         code = []
         for sheet_index, df_name in enumerate(post_state.df_names):
-            renames = execution_data['column_header_renames_list'][sheet_index] if execution_data else {}
+            renames = execution_data['column_header_renames_list'][sheet_index]
             if len(renames) == 0:
                 continue
 
@@ -117,14 +117,7 @@ class BulkOldRenameStepPerformer(StepPerformer):
     @classmethod
     def describe(
         cls,
-        df_names: List[str]=None,
-        **params: Any
+        df_names=None,
+        **params
     ) -> str:
         return f'Renamed headers for compatibility with previous Mito versions'
-
-    @classmethod
-    def get_modified_dataframe_indexes( # type: ignore
-        cls, 
-        **params
-    ) -> Set[int]:
-        return set() # changes all dataframes
\ No newline at end of file
