@@ -5,14 +5,12 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from mitosheet.state import State
 from typing import Any, Dict, List, Optional
+
+from mitosheet.errors import make_invalid_column_delete_error
+from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.errors import (
-    make_no_sheet_error,
-    make_no_column_error,
-    make_invalid_column_delete_error
-)
+
 
 class DeleteColumnStepPerformer(StepPerformer):
     """"
@@ -21,7 +19,7 @@ class DeleteColumnStepPerformer(StepPerformer):
     """
     @classmethod
     def step_version(cls) -> int:
-        return 1
+        return 2
 
     @classmethod
     def step_type(cls) -> str:
@@ -44,22 +42,17 @@ class DeleteColumnStepPerformer(StepPerformer):
         cls,
         prev_state: State,
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         **params
     ) -> State:
-        # if the sheet doesn't exist, throw an error
-        if not prev_state.does_sheet_index_exist_within_state(sheet_index):
-            raise make_no_sheet_error(sheet_index)
-
-        # Error if the column does not exist
-        if column_header not in prev_state.column_metatype[sheet_index]:
-            raise make_no_column_error([column_header])
+        
+        column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
         
         # Error if there are any columns that currently rely on this column
-        if len(prev_state.column_evaluation_graph[sheet_index][column_header]) > 0:
+        if len(prev_state.column_evaluation_graph[sheet_index][column_id]) > 0:
             raise make_invalid_column_delete_error(
                 column_header,
-                list(prev_state.column_evaluation_graph[sheet_index][column_header])
+                list(prev_state.column_evaluation_graph[sheet_index][column_id])
             )
 
         # Make a post state, that is a deep copy
@@ -70,15 +63,17 @@ class DeleteColumnStepPerformer(StepPerformer):
         df.drop(column_header, axis=1, inplace=True)
 
         # And then update all the state variables removing this column from the state
-        del post_state.column_metatype[sheet_index][column_header]
-        del post_state.column_type[sheet_index][column_header]
-        del post_state.column_spreadsheet_code[sheet_index][column_header]
-        del post_state.column_python_code[sheet_index][column_header]
-        del post_state.column_evaluation_graph[sheet_index][column_header]
+        del post_state.column_metatype[sheet_index][column_id]
+        del post_state.column_type[sheet_index][column_id]
+        del post_state.column_spreadsheet_code[sheet_index][column_id]
+        del post_state.column_python_code[sheet_index][column_id]
+        del post_state.column_evaluation_graph[sheet_index][column_id]
         # We also have to delete the places in the graph where this node is 
         for dependents in post_state.column_evaluation_graph[sheet_index].values():
-            if column_header in dependents:
-                dependents.remove(column_header)
+            if column_id in dependents:
+                dependents.remove(column_id)
+        # Clean up the IDs
+        post_state.column_ids.delete_column_id(sheet_index, column_id)
         
         return post_state, None
 
@@ -89,20 +84,22 @@ class DeleteColumnStepPerformer(StepPerformer):
         post_state: State,
         execution_data: Optional[Dict[str, Any]],
         sheet_index: int,
-        column_header: str
+        column_id: str
     ) -> List[str]:
         df_name = post_state.df_names[sheet_index]
+        column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
+
         return [f'{df_name}.drop(\'{column_header}\', axis=1, inplace=True)']
 
     @classmethod
     def describe(
         cls,
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         df_names=None,
         **params
     ) -> str:
         if df_names is not None:
             df_name = df_names[sheet_index]
-            return f'Deleted column {column_header} from {df_name}'
-        return f'Deleted column {column_header}'
\ No newline at end of file
+            return f'Deleted column {column_id} from {df_name}'
+        return f'Deleted column {column_id}'
