@@ -6,10 +6,11 @@
 
 from copy import copy
 from typing import Any, Dict, List, Optional
+
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.utils import make_valid_header
-from mitosheet.step_performers.dataframe_steps.dataframe_duplicate import get_first_unused_name
+from mitosheet.utils import get_valid_dataframe_name
+
 
 class DataframeRenameStepPerformer(StepPerformer):
     """"
@@ -83,31 +84,4 @@ class DataframeRenameStepPerformer(StepPerformer):
         df_names=None,
         **params
     ) -> str:
-        return f'Renamed {old_dataframe_name} to {new_dataframe_name}'
-
-
-def get_valid_python_variable_name(suggested_dataframe_name):
-    """
-    Turns the suggested dataframe name into a valid Python identifier.
-    """
-    # See: https://www.w3schools.com/python/ref_string_isidentifier.asp
-    if suggested_dataframe_name.isidentifier():
-        return suggested_dataframe_name
-
-    # First, we try and just fill in the non valid characters (like a column header)
-    valid_header_version = make_valid_header(suggested_dataframe_name)
-    if valid_header_version.isidentifier():
-        return valid_header_version
-
-    # Finially prefix with df, so that it doesn't start with a number (as vars cannot)
-    return f'df_{valid_header_version}'
-
-
-def get_valid_dataframe_name(df_names, suggested_dataframe_name):
-    """
-    Given an attempt at a dataframe name, makes sure that is a valid
-    dataframe name (e.g. it is a valid Python identifier, and it is
-    not a duplicate).
-    """
-    valid_identifier = get_valid_python_variable_name(suggested_dataframe_name)
-    return get_first_unused_name(df_names, valid_identifier)
\ No newline at end of file
+        return f'Renamed {old_dataframe_name} to {new_dataframe_name}'
\ No newline at end of file
