@@ -9,10 +9,6 @@ from copy import copy
 from typing import Any, Dict, List, Optional
 from mitosheet.state import DATAFRAME_SOURCE_MERGED, State
 from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.errors import (
-    make_no_sheet_error,
-    make_no_column_error,
-)
 
 
 class MergeStepPerformer(StepPerformer):
@@ -22,7 +18,7 @@ class MergeStepPerformer(StepPerformer):
 
     @classmethod
     def step_version(cls) -> int:
-        return 2
+        return 3
 
     @classmethod
     def step_type(cls) -> str:
@@ -46,28 +42,20 @@ class MergeStepPerformer(StepPerformer):
         prev_state: State,
         how: str,
         sheet_index_one: int,
-        merge_key_one: str,
-        selected_columns_one: List[str],
+        merge_key_column_id_one: str,
+        selected_column_ids_one: List[str],
         sheet_index_two: int,
-        merge_key_two: str,
-        selected_columns_two: List[str],
+        merge_key_column_id_two: str,
+        selected_column_ids_two: List[str],
         **params
     ) -> State:
-        # if the sheets don't exist, throw an error
-        if not prev_state.does_sheet_index_exist_within_state(sheet_index_one):
-            raise make_no_sheet_error(sheet_index_one)
 
-        if not prev_state.does_sheet_index_exist_within_state(sheet_index_two):
-            raise make_no_sheet_error(sheet_index_two)
+    
+        merge_key_one = prev_state.column_ids.get_column_header_by_id(sheet_index_one, merge_key_column_id_one)
+        merge_key_two = prev_state.column_ids.get_column_header_by_id(sheet_index_two, merge_key_column_id_two)
 
-        # We check that the merge doesn't use any columns that don't exist
-        missing_sheet_one_key = {merge_key_one}.difference(prev_state.column_metatype[sheet_index_one].keys())
-        if any(missing_sheet_one_key):
-            raise make_no_column_error(missing_sheet_one_key)
-
-        missing_sheet_two_key = {merge_key_two}.difference(prev_state.column_metatype[sheet_index_two].keys())
-        if any(missing_sheet_two_key):
-            raise make_no_column_error(missing_sheet_two_key)
+        selected_columns_one = prev_state.column_ids.get_column_headers_by_ids(sheet_index_one, selected_column_ids_one)
+        selected_columns_two = prev_state.column_ids.get_column_headers_by_ids(sheet_index_two, selected_column_ids_two)
 
         # We create a shallow copy to make the new post state
         post_state = copy(prev_state)
@@ -97,13 +85,19 @@ class MergeStepPerformer(StepPerformer):
         execution_data: Optional[Dict[str, Any]],
         how: str,
         sheet_index_one: int,
-        merge_key_one: str,
-        selected_columns_one: List[str],
+        merge_key_column_id_one: str,
+        selected_column_ids_one: List[str],
         sheet_index_two: int,
-        merge_key_two: str,
-        selected_columns_two: List[str]
+        merge_key_column_id_two: str,
+        selected_column_ids_two: List[str],
     ) -> List[str]:
 
+        merge_key_one = prev_state.column_ids.get_column_header_by_id(sheet_index_one, merge_key_column_id_one)
+        merge_key_two = prev_state.column_ids.get_column_header_by_id(sheet_index_two, merge_key_column_id_two)
+
+        selected_columns_one = prev_state.column_ids.get_column_headers_by_ids(sheet_index_one, selected_column_ids_one)
+        selected_columns_two = prev_state.column_ids.get_column_headers_by_ids(sheet_index_two, selected_column_ids_two)
+
         # update df indexes to start at 1
         df_one_name = post_state.df_names[sheet_index_one]
         df_two_name = post_state.df_names[sheet_index_two]
@@ -155,11 +149,11 @@ class MergeStepPerformer(StepPerformer):
         cls,
         how: str,
         sheet_index_one: int,
-        merge_key_one: str,
-        selected_columns_one: List[str],
+        merge_key_column_id_one: str,
+        selected_column_ids_one: List[str],
         sheet_index_two: int,
-        merge_key_two: str,
-        selected_columns_two: List[str],
+        merge_key_column_id_two: str,
+        selected_column_ids_two: List[str],
         df_names=None,
         **params
     ) -> str:
