@@ -13,6 +13,7 @@ CONSTANT_TEST_CASES = [
     (
         '=100',
         'B',
+        ['B'],
         'df[\'B\'] = 100',
         set([]),
         set([])
@@ -20,6 +21,7 @@ CONSTANT_TEST_CASES = [
     (
         '=True',
         'B',
+        ['B'],
         'df[\'B\'] = True',
         set([]),
         set([])
@@ -27,6 +29,7 @@ CONSTANT_TEST_CASES = [
     (
         '=\'StringSingleQuotes\'',
         'B',
+        ['B'],
         'df[\'B\'] = \'StringSingleQuotes\'',
         set([]),
         set([])
@@ -34,6 +37,7 @@ CONSTANT_TEST_CASES = [
     (
         '=\"StringDoubleQuotes\"',
         'B',
+        ['B'],
         'df[\'B\'] = \"StringDoubleQuotes\"',
         set([]),
         set([])
@@ -41,6 +45,7 @@ CONSTANT_TEST_CASES = [
     (
         '=\"String Double Quotes\"',
         'B',
+        ['B'],
         'df[\'B\'] = \"String Double Quotes\"',
         set([]),
         set([])
@@ -48,6 +53,7 @@ CONSTANT_TEST_CASES = [
     (
         '=FUNC(\"String Double Quotes\")',
         'B',
+        ['B'],
         'df[\'B\'] = FUNC(\"String Double Quotes\")',
         set(['FUNC']),
         set([])
@@ -55,6 +61,7 @@ CONSTANT_TEST_CASES = [
     (
         '=FUNC(\"DIFF_FUNC(A)\")',
         'B',
+        ['B'],
         'df[\'B\'] = FUNC(\"DIFF_FUNC(A)\")',
         set(['FUNC']),
         set([])
@@ -62,6 +69,7 @@ CONSTANT_TEST_CASES = [
     (
         '=\"String One FUNC(A)\" + \"STRING TWO FUNC(A)\"',
         'B',
+        ['B'],
         'df[\'B\'] = \"String One FUNC(A)\" + \"STRING TWO FUNC(A)\"',
         set([]),
         set([])
@@ -69,6 +77,7 @@ CONSTANT_TEST_CASES = [
     (
         '=\'String One FUNC(A)\' + \'STRING TWO FUNC(A)\'',
         'B',
+        ['B'],
         'df[\'B\'] = \'String One FUNC(A)\' + \'STRING TWO FUNC(A)\'',
         set([]),
         set([])
@@ -76,6 +85,7 @@ CONSTANT_TEST_CASES = [
     (
         '=FUNC1(\'String One FUNC(A)\') + FUNC2(\'STRING TWO FUNC(A)\')',
         'B',
+        ['B'],
         'df[\'B\'] = FUNC1(\'String One FUNC(A)\') + FUNC2(\'STRING TWO FUNC(A)\')',
         set(['FUNC1', 'FUNC2']),
         set([])
@@ -88,6 +98,7 @@ OPERATOR_TEST_CASES = [
     (
         '=A + B',
         'C',
+        ['A', 'B', 'C'],
         'df[\'C\'] = df[\'A\'] + df[\'B\']',
         set(),
         set(['A', 'B'])
@@ -96,6 +107,7 @@ OPERATOR_TEST_CASES = [
     (
         '=A - B',
         'C',
+        ['A', 'B', 'C'],
         'df[\'C\'] = df[\'A\'] - df[\'B\']',
         set(),
         set(['A', 'B'])
@@ -104,6 +116,7 @@ OPERATOR_TEST_CASES = [
     (
         '=A * B',
         'C',
+        ['A', 'B', 'C'],
         'df[\'C\'] = df[\'A\'] * df[\'B\']',
         set(),
         set(['A', 'B'])
@@ -112,6 +125,7 @@ OPERATOR_TEST_CASES = [
     (
         '=A / B',
         'C',
+        ['A', 'B', 'C'],
         'df[\'C\'] = df[\'A\'] / df[\'B\']',
         set(),
         set(['A', 'B'])
@@ -120,6 +134,7 @@ OPERATOR_TEST_CASES = [
     (
         '=AAA + BBB + CCC + DDD',
         'E',
+        ['AAA', 'BBB', 'CCC', 'DDD'],
         'df[\'E\'] = df[\'AAA\'] + df[\'BBB\'] + df[\'CCC\'] + df[\'DDD\']',
         set(),
         set(['AAA', 'BBB', 'CCC', 'DDD'])
@@ -128,6 +143,7 @@ OPERATOR_TEST_CASES = [
     (
         '=(A + B) / C + A * 100',
         'D',
+        ['A', 'B', 'C'],
         'df[\'D\'] = (df[\'A\'] + df[\'B\']) / df[\'C\'] + df[\'A\'] * 100',
         set(),
         set(['A', 'B', 'C'])
@@ -136,6 +152,7 @@ OPERATOR_TEST_CASES = [
     (
         '=FUNC(A + B / C + A * 100)',
         'D',
+        ['A', 'B', 'C'],
         'df[\'D\'] = FUNC(df[\'A\'] + df[\'B\'] / df[\'C\'] + df[\'A\'] * 100)',
         set(['FUNC']),
         set(['A', 'B', 'C'])
@@ -148,6 +165,7 @@ FUNCTION_TEST_CASES = [
     (
         '=FUNC(A)',
         'B',
+        ['A', 'B', 'C'],
         'df[\'B\'] = FUNC(df[\'A\'])',
         set(['FUNC']),
         set(['A'])
@@ -156,6 +174,7 @@ FUNCTION_TEST_CASES = [
     (
         '=C(A)',
         'B',
+        ['A', 'B', 'C'],
         'df[\'B\'] = C(df[\'A\'])',
         set(['C']),
         set(['A'])
@@ -164,6 +183,7 @@ FUNCTION_TEST_CASES = [
     (
         '=FUNCA(FUNCB(FUNCC(FUNCD(FUNCE(FUNCF(FUNCG(FUNCH(A))))))))',
         'B',
+        ['A', 'B', 'C'],
         'df[\'B\'] = FUNCA(FUNCB(FUNCC(FUNCD(FUNCE(FUNCF(FUNCG(FUNCH(df[\'A\']))))))))',
         set(['FUNCA', 'FUNCB', 'FUNCC', 'FUNCD', 'FUNCE', 'FUNCF', 'FUNCG', 'FUNCH']),
         set(['A'])
@@ -172,6 +192,7 @@ FUNCTION_TEST_CASES = [
     (
         '=RIGHT(A, LEN(B) - 10)',
         'C',
+        ['A', 'B', 'C'],
         'df[\'C\'] = RIGHT(df[\'A\'], LEN(df[\'B\']) - 10)',
         set(['RIGHT', 'LEN']),
         set(['A', 'B'])
@@ -180,6 +201,7 @@ FUNCTION_TEST_CASES = [
     (
         '=FUNC(A, FUNC(B, FUNC(C)))',
         'D',
+        ['A', 'B', 'C'],
         'df[\'D\'] = FUNC(df[\'A\'], FUNC(df[\'B\'], FUNC(df[\'C\'])))',
         set(['FUNC']),
         set(['A', 'B', 'C'])
@@ -188,6 +210,7 @@ FUNCTION_TEST_CASES = [
     (
         '=FUNC(A, B, C, D, E, F, G, H, I)',
         'J',
+        ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I'],
         'df[\'J\'] = FUNC(df[\'A\'], df[\'B\'], df[\'C\'], df[\'D\'], df[\'E\'], df[\'F\'], df[\'G\'], df[\'H\'], df[\'I\'])',
         set(['FUNC']),
         set(['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I'])
@@ -196,26 +219,74 @@ FUNCTION_TEST_CASES = [
     (
         '=FUNC(column1, column2)',
         'J',
+        ['column1', 'column2', 'J'],
         'df[\'J\'] = FUNC(df[\'column1\'], df[\'column2\'])',
         set(['FUNC']),
         set(['column1', 'column2'])
     ),
-    # Test references to columns with underscores
+    # Test references to columns with spaces
     (
-        '=FUNC(column_1, column_2)',
+        '=FUNC(column 1, column 2)',
         'J',
-        'df[\'J\'] = FUNC(df[\'column_1\'], df[\'column_2\'])',
+        ['column 1', 'column 2', 'J'],
+        'df[\'J\'] = FUNC(df[\'column 1\'], df[\'column 2\'])',
         set(['FUNC']),
-        set(['column_1', 'column_2'])
+        set(['column 1', 'column 2'])
     ),
-    # Test references to columns that are lookups
+    # Test references to columns that are numbers
     (
-        '=FUNC(LOOKUP, XLOOKUP, VLOOKUP, HLOOKUP)',
+        '=FUNC(123, 456)',
         'J',
-        'df[\'J\'] = FUNC(df[\'LOOKUP\'], df[\'XLOOKUP\'], df[\'VLOOKUP\'], df[\'HLOOKUP\'])',
+        [123, 456, 'J'],
+        'df[\'J\'] = FUNC(df[123], df[456])',
         set(['FUNC']),
-        set(['LOOKUP', 'XLOOKUP', 'VLOOKUP', 'HLOOKUP'])
-    ) 
+        set([123, 456])
+    ),
+    # Test references to columns that are numbers and are also strings
+    (
+        '=FUNC(123, 456, abc)',
+        'J',
+        ['abc', 456, 123, "J"],
+        'df[\'J\'] = FUNC(df[123], df[456], df[\'abc\'])',
+        set(['FUNC']),
+        set([123, 456, 'abc'])
+    ),
+    # Test references to strings that has a single quotes in it
+    (
+        '=FUNC(this is a string \' that has a quote, 456, abc)',
+        'J',
+        ['abc', 456, 'this is a string \' that has a quote', "J"],
+        'df[\'J\'] = FUNC(df[\'this is a string \' that has a quote\'], df[456], df[\'abc\'])',
+        set(['FUNC']),
+        set(['abc', 456, 'this is a string \' that has a quote'])
+    ),
+    # Test references to strings that have mulitple quotes
+    (
+        '=FUNC(this is a string \'test\' that has a quote, 456, abc)',
+        'J',
+        ['abc', 456, 'this is a string \'test\' that has a quote', "J"],
+        'df[\'J\'] = FUNC(df[\'this is a string \'test\' that has a quote\'], df[456], df[\'abc\'])',
+        set(['FUNC']),
+        set(['abc', 456, 'this is a string \'test\' that has a quote'])
+    ),
+    # Test references to a string in quotes, but is a column header
+    (
+        '=FUNC("column")',
+        'J',
+        ["\"column\"", "J"],
+        'df[\'J\'] = FUNC(df[\'"column"\'])',
+        set(['FUNC']),
+        set(["\"column\""])
+    ),
+    # Test references to a quote that is covered by a column header
+    (
+        '=FUNC("this is a string")',
+        'J',
+        ["string", "J"],
+        'df[\'J\'] = FUNC("this is a string")',
+        set(['FUNC']),
+        set([])
+    ),
 ]
 
 
@@ -229,9 +300,9 @@ Order of params is: formula, address, python_code, functions, columns
 See documentation here: https://docs.pytest.org/en/latest/parametrize.html#parametrize-basics
 """
 PARSE_TESTS = CONSTANT_TEST_CASES + OPERATOR_TEST_CASES + FUNCTION_TEST_CASES
-@pytest.mark.parametrize("formula,address,python_code,functions,columns", PARSE_TESTS)
-def test_parse(formula, address, python_code, functions, columns):
-    assert parse_formula(formula, address) == \
+@pytest.mark.parametrize("formula,column_header,column_headers,python_code,functions,columns", PARSE_TESTS)
+def test_parse(formula, column_header, column_headers, python_code, functions, columns):
+    assert parse_formula(formula, column_header, column_headers) == \
         (
             python_code, 
             functions, 
@@ -250,33 +321,32 @@ PARSE_TEST_ERRORS = [
 @pytest.mark.parametrize("formula, address, error_type, to_fix_substr", PARSE_TEST_ERRORS)
 def test_parse_errors(formula, address, error_type, to_fix_substr):
     with pytest.raises(EditError) as e_info:
-        parse_formula(formula, address)
+        parse_formula(formula, address, ['A', 'B'])
     assert e_info.value.type_ == error_type
     if to_fix_substr is not None:
         assert to_fix_substr in e_info.value.to_fix
 
 
 SAFE_REPLACE_TESTS = [
-    ('=A', 'A', 'B', '=B'),
-    ('=A + A', 'A', 'B', '=B + B'),
-    ('=A + B', 'A', 'B', '=B + B'),
-    ('=A + B + A', 'A', 'B', '=B + B + B'),
-    ('=A + B + \"A\"', 'A', 'B', '=B + B + \"A\"'),
-    ('=A + B + \'A\'', 'A', 'B', '=B + B + \'A\''),
-    ('=A + B + \'A\'', 'A', 'B', '=B + B + \'A\''),
-    ('=FUNC(A, B, A) + TEST(FUNC(A, \'A\', \'B\')) + \'A\'', 'A', 'B', '=FUNC(B, B, B) + TEST(FUNC(B, \'A\', \'B\')) + \'A\''),
-    ('=APPLE(A, B, A) + AARON(AAA(A, \'A\', \'B\')) + \'A\'', 'A', 'B', '=APPLE(B, B, B) + AARON(AAA(B, \'A\', \'B\')) + \'A\''),
+    ('=A', 'A', 'B', ['A', 'B'], '=B'),
+    ('=A + A', 'A', 'B', ['A', 'B'], '=B + B'),
+    ('=A + B', 'A', 'B', ['A', 'B'], '=B + B'),
+    ('=A + B + A', 'A', 'B', ['A', 'B'], '=B + B + B'),
+    ('=This is a test', 'test', 'B', ['This is a test'], '=This is a test'),
+    ('="test with spaces"', 'test with spaces', 'B', ['test with spaces'], '="test with spaces"'),
+    ('=A + B + \"A\"', 'A', 'B', ['A', 'B'], '=B + B + \"A\"'),
+    ('=A + B + \'A\'', 'A', 'B', ['A', 'B'], '=B + B + \'A\''),
+    ('=A + B + \'A\'', 'A', 'B', ['A', 'B'], '=B + B + \'A\''),
+    ('=FUNC(A, B, A) + TEST(FUNC(A, \'A\', \'B\')) + \'A\'', 'A', 'B', ['A', 'B'], '=FUNC(B, B, B) + TEST(FUNC(B, \'A\', \'B\')) + \'A\''),
+    ('=APPLE(A, B, A) + AARON(AAA(A, \'A\', \'B\')) + \'A\'', 'A', 'B', ['A', 'B'], '=APPLE(B, B, B) + AARON(AAA(B, \'A\', \'B\')) + \'A\''),
 ]
 
-@pytest.mark.parametrize('formula,old_text,new_text,new_formula', SAFE_REPLACE_TESTS)
-def test_safe_replace(formula, old_text, new_text, new_formula):
-    assert safe_replace(formula, old_text, new_text) == new_formula
+@pytest.mark.parametrize('formula,old_column_header,new_column_header,column_headers,new_formula', SAFE_REPLACE_TESTS)
+def test_safe_replace(formula, old_column_header, new_column_header, column_headers, new_formula):
+    assert safe_replace(formula, old_column_header, new_column_header, column_headers) == new_formula
 
 
 SAFE_CONTAINS_TESTS = [
-    ('=A', 'A', True),
-    ('=A + B', 'B', True),
-    ('=A + "B"', 'B', False),
     ('=A & "B"', '&', True),
     ('=A - +  "&"', '&', False),
     ('=A - +  \'&\'', '&', False),
@@ -284,4 +354,4 @@ SAFE_CONTAINS_TESTS = [
 
 @pytest.mark.parametrize('formula,substring,contains', SAFE_CONTAINS_TESTS)
 def test_safe_contains(formula, substring, contains):
-    assert safe_contains(formula, substring) == contains
\ No newline at end of file
+    assert safe_contains(formula, substring, ['A', 'B']) == contains
\ No newline at end of file
