@@ -19,6 +19,7 @@ from mitosheet.step_performers import (
     ReorderColumnStepPerformer,
     AddColumnStepPerformer,
     SetColumnFormulaStepPerformer,
+    SetCellValueStepPerformer,
     MergeStepPerformer,
     DeleteColumnStepPerformer,
     RenameColumnStepPerformer,
@@ -26,7 +27,8 @@ from mitosheet.step_performers import (
     SimpleImportStepPerformer,
     DataframeDeleteStepPerformer,
     DataframeDuplicateStepPerformer,
-    DataframeRenameStepPerformer
+    DataframeRenameStepPerformer,
+    BulkOldRenameStepPerformer
 )
 
 def check_step(
@@ -70,62 +72,62 @@ def test_params_static():
 
     check_step(
         DeleteColumnStepPerformer,
-        1,
+        2,
         'delete_column'
     )
 
     check_step(
         RenameColumnStepPerformer,
-        1,
+        2,
         'rename_column'
     )
 
     check_step(
         FilterStepPerformer,
-        2,
+        3,
         'filter_column'
     )
     
     check_step(
         PivotStepPerformer,
-        3,
+        5,
         'pivot'
     )
 
     check_step(
         MergeStepPerformer,
-        2,
+        3,
         'merge'
     )
 
     check_step(
         ReorderColumnStepPerformer,
-        1,
+        2,
         'reorder_column'
     )
 
     check_step(
         SetColumnFormulaStepPerformer,
-        1,
+        2,
         'set_column_formula'
     )
 
     check_step(
         SortStepPerformer,
-        1,
+        2,
         'sort'
     )
 
 
     check_step(
         ChangeColumnDtypeStepPerformer,
-        1,
+        2,
         'change_column_dtype'
     )
 
     check_step(
         SimpleImportStepPerformer,
-        1,
+        2,
         'simple_import'
     )
 
@@ -147,7 +149,19 @@ def test_params_static():
         'dataframe_rename'
     )
 
-    assert len(STEP_PERFORMERS) == 14
+    check_step(
+        SetCellValueStepPerformer,
+        1,
+        'set_cell_value'
+    )
+
+    check_step(
+        BulkOldRenameStepPerformer,
+        1,
+        'bulk_old_rename'
+    )
+
+    assert len(STEP_PERFORMERS) == 16
 
 
 def get_fake_param(param_name):
