@@ -9,7 +9,7 @@ Exports the transpile function, which takes the backend widget
 container and generates transpiled Python code.
 """
 
-from mitosheet.preprocessing import PREPROCESS_STEPS
+from mitosheet.preprocessing import PREPROCESS_STEP_PERFORMERS
 
 
 IN_PREVIOUS_STEP_COMMENT = '# You\'re viewing a previous step. Click fast forward in the Mitosheet above to see the full analysis.'
@@ -26,8 +26,11 @@ def transpile(steps_manager, add_comments=True):
     code = []
 
     # First, we transpile all the preprocessing steps
-    for PREPROCESS_STEP in PREPROCESS_STEPS:
-        preprocess_code = PREPROCESS_STEP['transpile'](steps_manager)
+    for preprocess_step_performer in PREPROCESS_STEP_PERFORMERS:
+        preprocess_code = preprocess_step_performer.transpile(
+            steps_manager,
+            steps_manager.preprocess_execution_data[preprocess_step_performer.preprocess_step_type()]
+        )
         if len(preprocess_code) > 0:
             code.extend(preprocess_code)
 
@@ -59,7 +62,7 @@ def transpile(steps_manager, add_comments=True):
             **step.params
         )
         
-        # Make sure we don't add comments for steps with no code
+        # Make sure to not generate comments or code for steps with no code 
         if len(transpiled_code) > 0:
 
             step_code.extend(
